@@ -124,7 +124,7 @@ static FORCEINLINE CV* _method (pTHX_ HV* selfstash, GV* context, SV* fqnsv) {
     STRLEN stashname_len = HvNAMELEN(stash);
 
     /* has ourselves at the top of the list */
-    static const mro_alg*const algo = Perl_mro_get_from_name(aTHX_ sv_2mortal(newSVpvs("c3")));
+    const mro_alg*const algo = Perl_mro_get_from_name(aTHX_ sv_2mortal(newSVpvs("c3")));
     AV* linear_av = algo->resolve(aTHX_ selfstash, 0);
     SV** linear_svp = AvARRAY(linear_av);
     I32 entries = AvFILLp(linear_av) + 1;
